extends MeshInstance

# stair speed
var speed = 2

# variable to store y/z ratio
var yzRatio

# variable to store the amount of steps
var steps

# Called when the node enters the scene tree for the first time.
func _ready() :
	
	# determine y/z ratio
	yzRatio = mesh.size.y / mesh.size.z
	
	# get steps value from Spatial node
	steps = get_node('/root/Spatial').get('steps')
	
	# custom function to place the spike
	placeSpike()
	
# This function positions the spike randomly along the step
func placeSpike() :
	
	# now we determine the half width of the step, and we subtract 1
	# this is the half range where we are going to place the spike
	# if the step has width = 10, halfPositionRange will be 10 / 2 - 1 = 4
	# this means we'll place the spike in a random position between -4 and 4
	var halfPositionRange = (mesh.size.x) / 2 - 1
	
	# and this is how we toss a random integer number in the range -n, n
	var randomPosition = get_node('/root/Spatial').get('rnd').randi_range(-halfPositionRange, halfPositionRange)
	
	# now we get the first child of the step (the spike) and place it in the random position
	get_child(0).translation.x = randomPosition

# Called every frame. 'delta' is the elapsed time since the previous frame.
func _process(delta) :
	
	# move the step along y axis according to speed and elapsed time
	translation.y -= delta * speed
	
	# move the step along z axis according to speed, elapsed time and y/z ratio
	# y/z ratio is necessary because y and z speed cannot be the same as steps
	# do not have the same size so the stair does not have a 45 degrees angle
	translation.z += delta * speed / yzRatio
	
	# is z position greater than mesh z size, making the step to be outside camera eye?
	if (translation.z > mesh.size.z) :
		
		# move the step along y axis as if it were the highest step
		translation.y += steps * mesh.size.y
		
		# move the step along z axis as if it were the furthest step
		translation.z += steps * mesh.size.z * - 1
		
		# place the spike in a random position
		placeSpike()
